#' Correction for unreliability 
#'
#'The amount of unrealibility is estimated to calculate the disattenuated effect size.The observed effect size and variances were corrected for a precise effect size estimation.     
#'@param rxx    Reliability estimate for variable x
#'@param ryy    Reliability estimate for variable y
#'@param ESzr   Fisher's transformed effect size  (ESzr)
#'@param Varzr  variance for Fisher's transformed effect size  (ESzr)
#'@return Adjusted Fisher's transformed effect size  (ESzr)
#'@return Adjusted variance for the Fisher's transformed r (Varzr)
#'@examples
#'ESr_adjusted (.82, .81, .19, .0498)
#'@export
ESr_adjusted <-function (rxx, ryy, ESzr, Varzr)
{
  aunreliability <- sqrt((rxx)*(ryy))
  ESr_ad <-ESzr/aunreliability
  Var_ad <-Varzr/aunreliability
  return (setNames((list(ESr_ad, Var_ad)),c("Effect Size", "Variance")))  
}

#' Correction for artificial dichotomization 
#'
#'Artificial dichotomization from a continous variable is accounted and corrected in the estimation of the effect size and the variance of the effect size.      
#'@param p      Proportion in each group 
#'@param q      Proportion in each group
#'@param c      Artifact correction for proportional dichotomization
#'@param ESzr   Fisher's transformed effect size  (ESzr)
#'@param Varzr  variance for Fisher's transformed effect size  (ESzr)
#'@return Adjusted Fisher's transformed effect size  (ESzr)
#'@return Adjusted variance for the Fisher's transformed r (Varzr)
#'@examples
#'ESr_dichotom (.839, .161, .243, .16, .0453)
#'If a total sample in a group is 200, 90 (45%) was  classified as depressed and 110 (55%) as not depressed. With this example, p = 0.45, then q = 0.55. 
#'The c value can be obtained for the .45/.55 spilt from the artifact dichotomization table.
#'@export
ESr_dichotom <-function (p, q, c, ESzr, Varzr)
{
  adichotomization <- (c/(sqrt(p*q)))
  ESr_ad <-ESzr/adichotomization
  Var_ad <-Varzr/adichotomization
  return (setNames((list(ESr_ad, Var_ad)),c("Effect Size", "Variance")))  
}

