#' Transforming Cronbach's alpha to Effect size 
#'
#'The Cronbach's alpha is transformed to an effect size.  
#'@param a     Cronbach's alpha value
#'@param j     Number of items on the scale used in the study
#'@param N     Total sample size of the study
#'@return Effect size  (ESr)
#'@return Variance for the Fisher's transformed r (Var)
#'@examples
#'ESra (0.8, 20, 100)
#'@export
ESra <-function (a, j, N)
{
  ESa <- (((1-a)^(1/3)))
  SEESa <-sqrt(((18*j)*(N-1)*((1-a)^(2/3)))/((j-1)*(((9*N)-11)^2)))
  Var <-(SEESa^2)
  A <- 1-((ESa^3))
  return (setNames((list(ESa, Var, A)),c("Effect Size", "Variance", "Back transformation of Cronbach's alpha")))  
}
ESra (0.8, 20, 100)

